==> jc-1.4.0.tar.gz: java/beans/VetoableChangeListenerProxy.h <==
// public class java.beans.VetoableChangeListenerProxy

// class file dependencies
// @dep_class 720110b64c695110 java_beans_VetoableChangeListenerProxy
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5aac94d3604b130b java_util_EventListenerProxy

// header file dependencies
// @dep_header java_util_EventListenerProxy

#include "java/util/EventListenerProxy.h"

#ifndef _JC_java_beans_VetoableChangeListenerProxy_H_
#define _JC_java_beans_VetoableChangeListenerProxy_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_beans_VetoableChangeListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_VetoableChangeListenerProxy$sub_refs	_jc_java_beans_VetoableChangeListenerProxy$sub_refs;
typedef struct _jc_java_beans_VetoableChangeListenerProxy$sub_nonrefs	_jc_java_beans_VetoableChangeListenerProxy$sub_nonrefs;
typedef struct _jc_java_beans_VetoableChangeListenerProxy$refs	_jc_java_beans_VetoableChangeListenerProxy$refs;
typedef struct _jc_java_beans_VetoableChangeListenerProxy$nonrefs	_jc_java_beans_VetoableChangeListenerProxy$nonrefs;
typedef struct _jc_java_beans_VetoableChangeListenerProxy$object	_jc_java_beans_VetoableChangeListenerProxy$object;

typedef const struct _jc_java_beans_VetoableChangeListenerProxy$vmethods	_jc_java_beans_VetoableChangeListenerProxy$vmethods;
typedef const struct _jc_java_beans_VetoableChangeListenerProxy$vtable	_jc_java_beans_VetoableChangeListenerProxy$vtable;
typedef const struct _jc_java_beans_VetoableChangeListenerProxy$vtype	_jc_java_beans_VetoableChangeListenerProxy$vtype;

// Constructors
extern void _jc_java_beans_VetoableChangeListenerProxy$method$_init$d0d91b97e78b07e1(_jc_env *, struct _jc_java_beans_VetoableChangeListenerProxy$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_beans_VetoableChangeListenerProxy$method$getPropertyName$3ce73dcd3d514390(_jc_env *, struct _jc_java_beans_VetoableChangeListenerProxy$object *);
extern void _jc_java_beans_VetoableChangeListenerProxy$method$vetoableChange$44daa4c05de6ba74(_jc_env *, struct _jc_java_beans_VetoableChangeListenerProxy$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_VetoableChangeListenerProxy$method_info$getPropertyName$3ce73dcd3d514390;
extern _jc_method _jc_java_beans_VetoableChangeListenerProxy$method_info$vetoableChange$44daa4c05de6ba74;

// Virtual methods structure
struct _jc_java_beans_VetoableChangeListenerProxy$vmethods {
	struct _jc_java_lang_String$object	*(*getPropertyName$3ce73dcd3d514390)(_jc_env *, struct _jc_java_beans_VetoableChangeListenerProxy$object *);
	void	(*vetoableChange$44daa4c05de6ba74)(_jc_env *, struct _jc_java_beans_VetoableChangeListenerProxy$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
};

// Vtable
struct _jc_java_beans_VetoableChangeListenerProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventListenerProxy$vmethods	java_util_EventListenerProxy;
	_jc_java_beans_VetoableChangeListenerProxy$vmethods	java_beans_VetoableChangeListenerProxy;
};

// Vtype
struct _jc_java_beans_VetoableChangeListenerProxy$vtype {
	_jc_type			type;
	_jc_java_beans_VetoableChangeListenerProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_VetoableChangeListenerProxy$sub_refs {
	struct _jc_java_lang_String$object	*propertyName;
};

// Reference instance fields (object)
struct _jc_java_beans_VetoableChangeListenerProxy$refs {
    _jc_java_beans_VetoableChangeListenerProxy$sub_refs	java_beans_VetoableChangeListenerProxy;
    _jc_java_util_EventListenerProxy$sub_refs	java_util_EventListenerProxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_VetoableChangeListenerProxy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_VetoableChangeListenerProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventListenerProxy$sub_nonrefs	java_util_EventListenerProxy;
    _jc_java_beans_VetoableChangeListenerProxy$sub_nonrefs	java_beans_VetoableChangeListenerProxy;
};

// Object instance structure
struct _jc_java_beans_VetoableChangeListenerProxy$object {
	_jc_java_beans_VetoableChangeListenerProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_VetoableChangeListenerProxy$vtype	*vtype;
	_jc_java_beans_VetoableChangeListenerProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_VetoableChangeListenerProxy$vtype _jc_java_beans_VetoableChangeListenerProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_VetoableChangeListenerProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_VetoableChangeListenerProxy$class_object;

#endif	/* _JC_java_beans_VetoableChangeListenerProxy_H_ */

==> jc-1.4.6.tar.gz: java/beans/VetoableChangeListenerProxy.h <==
// public class java.beans.VetoableChangeListenerProxy

// class file dependencies
// @dep_class 720110b64c695110 java_beans_VetoableChangeListenerProxy
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5aac94d3604b130b java_util_EventListenerProxy

// header file dependencies
// @dep_header java_util_EventListenerProxy

#include "java/util/EventListenerProxy.h"

#ifndef _JC_java_beans_VetoableChangeListenerProxy_H_
#define _JC_java_beans_VetoableChangeListenerProxy_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_beans_VetoableChangeListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_VetoableChangeListenerProxy$sub_refs	_jc_java_beans_VetoableChangeListenerProxy$sub_refs;
typedef struct _jc_java_beans_VetoableChangeListenerProxy$sub_nonrefs	_jc_java_beans_VetoableChangeListenerProxy$sub_nonrefs;
typedef struct _jc_java_beans_VetoableChangeListenerProxy$refs	_jc_java_beans_VetoableChangeListenerProxy$refs;
typedef struct _jc_java_beans_VetoableChangeListenerProxy$nonrefs	_jc_java_beans_VetoableChangeListenerProxy$nonrefs;
typedef struct _jc_java_beans_VetoableChangeListenerProxy$object	_jc_java_beans_VetoableChangeListenerProxy$object;

typedef const struct _jc_java_beans_VetoableChangeListenerProxy$vmethods	_jc_java_beans_VetoableChangeListenerProxy$vmethods;
typedef const struct _jc_java_beans_VetoableChangeListenerProxy$vtable	_jc_java_beans_VetoableChangeListenerProxy$vtable;
typedef const struct _jc_java_beans_VetoableChangeListenerProxy$vtype	_jc_java_beans_VetoableChangeListenerProxy$vtype;

// Constructors
extern void _jc_java_beans_VetoableChangeListenerProxy$method$_init$d0d91b97e78b07e1(_jc_env *, struct _jc_java_beans_VetoableChangeListenerProxy$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_beans_VetoableChangeListenerProxy$method$getPropertyName$3ce73dcd3d514390(_jc_env *, struct _jc_java_beans_VetoableChangeListenerProxy$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_VetoableChangeListenerProxy$method$vetoableChange$44daa4c05de6ba74(_jc_env *, struct _jc_java_beans_VetoableChangeListenerProxy$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_VetoableChangeListenerProxy$method_info$getPropertyName$3ce73dcd3d514390;
extern _jc_method _jc_java_beans_VetoableChangeListenerProxy$method_info$vetoableChange$44daa4c05de6ba74;

// Virtual methods structure
struct _jc_java_beans_VetoableChangeListenerProxy$vmethods {
	struct _jc_java_lang_String$object	*(*getPropertyName$3ce73dcd3d514390)(_jc_env *, struct _jc_java_beans_VetoableChangeListenerProxy$object *) _JC_JCNI_ATTR;
	void	(*vetoableChange$44daa4c05de6ba74)(_jc_env *, struct _jc_java_beans_VetoableChangeListenerProxy$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_VetoableChangeListenerProxy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventListenerProxy$vmethods	java_util_EventListenerProxy;
	_jc_java_beans_VetoableChangeListenerProxy$vmethods	java_beans_VetoableChangeListenerProxy;
};

// Vtype
struct _jc_java_beans_VetoableChangeListenerProxy$vtype {
	_jc_type			type;
	_jc_java_beans_VetoableChangeListenerProxy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_VetoableChangeListenerProxy$sub_refs {
	struct _jc_java_lang_String$object	*propertyName;
};

// Reference instance fields (object)
struct _jc_java_beans_VetoableChangeListenerProxy$refs {
    _jc_java_beans_VetoableChangeListenerProxy$sub_refs	java_beans_VetoableChangeListenerProxy;
    _jc_java_util_EventListenerProxy$sub_refs	java_util_EventListenerProxy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_VetoableChangeListenerProxy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_VetoableChangeListenerProxy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventListenerProxy$sub_nonrefs	java_util_EventListenerProxy;
    _jc_java_beans_VetoableChangeListenerProxy$sub_nonrefs	java_beans_VetoableChangeListenerProxy;
};

// Object instance structure
struct _jc_java_beans_VetoableChangeListenerProxy$object {
	_jc_java_beans_VetoableChangeListenerProxy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_VetoableChangeListenerProxy$vtype	*vtype;
	_jc_java_beans_VetoableChangeListenerProxy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_VetoableChangeListenerProxy$vtype _jc_java_beans_VetoableChangeListenerProxy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_VetoableChangeListenerProxy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_VetoableChangeListenerProxy$class_object;

#endif	/* _JC_java_beans_VetoableChangeListenerProxy_H_ */
